@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -45,9 +45,9 @@ QString LocalResourceCreator::akonadiNotesInstanceName()
 
 void LocalResourceCreator::createIfMissing()
 {
-    Akonadi::AgentInstance::List instances = Akonadi::AgentManager::self()->instances();
+    const Akonadi::AgentInstance::List instances = Akonadi::AgentManager::self()->instances();
     bool found = false;
-    foreach (const Akonadi::AgentInstance &instance, instances) {
+    for (const Akonadi::AgentInstance &instance : instances) {
         if (instance.type().identifier() == akonadiNotesInstanceName()) {
             found = true;
             break;
