@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class KNotesWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit KNotesWidget(KNotesPart *part, QWidget *parent = Q_NULLPTR);
+    explicit KNotesWidget(KNotesPart *part, QWidget *parent = nullptr);
     ~KNotesWidget();
 
     KNotesIconView *notesView() const;
